// file    : ButtonReader.cpp
// brief   : defines "control reader" for push buttons
// author  : SGRY (YAMAMOTO Suguru)
// update  : 2007-06-15 (SGRY)
// license : MIT License (see END of this file)
//=========================================================
#include "ButtonReader.h"

//=========================================================
//
//  Init / Dispose
//
//=========================================================

ButtonReader::ButtonReader( ISpeakable * speaker )
	: ControlReader( speaker )
{}

ButtonReader::~ButtonReader()
{}


//=========================================================
//
//  ControlReader interface
//
//=========================================================

//-------------------------------------
// function : ButtonReader::CanHandleContext
// brief    : determine whether this class can handle the event sent from AccessBridge
//-------------------------------------
bool
ButtonReader::CanHandleContext( long vmID, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	// check if the context was from proper Swing control
	if( wcscmp(contextInfo.role_en_US, ACCESSIBLE_PUSH_BUTTON) != 0 )
	{
		return false;
	}

	return true;
	vmID; context;
}

//-------------------------------------
// function : ButtonReader::OnFocusGained
//-------------------------------------
void
ButtonReader::OnFocusGained( long vmID, FocusEvent event, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	wstring name, type;
	bool opensNewWindow = false;

	// in some cases, this event was occur when the OTHER control have focused.
	// so in such cases, ignore this event.
	if( wcsstr(contextInfo.states_en_US, L"focused") == 0 )
	{
		return;
	}

	// if the label ends with "...", replace it
	name = contextInfo.name;
	if( Utl::EndsWith(name, L"...") )
	{
		opensNewWindow = true;
		name.resize( name.length() - 3 ); // erase trailing "..."
		name.append( _SpeakerRef->GetTextForTripleDots() );
	}

	// make speech text
	name = Utl::Format( Utl::GetString("ButtonReader.Name", "{0} ").c_str(), name.c_str() );
	type = Utl::GetString( "ButtonReader.Type", "button" ).c_str();

	// speech
	_SpeakerRef->ShutUp();
	_SpeakerRef->Speak( name );
	_SpeakerRef->Wait( false );
	_SpeakerRef->Speak( type );

	ControlReader::OnFocusGained( vmID, event, context, contextInfo );
}


/**********************************************************
Copyright (c) 2006-2007 YAMAMOTO Suguru

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
**********************************************************/
