// file    : GenericReader.cpp
// brief   : defines "control reader" for unknown components
// author  : SGRY (YAMAMOTO Suguru)
// update  : 2007-03-01 (SGRY)
// license : MIT License (see END of this file)
//=========================================================
#include "GenericControlReader.h"

//=========================================================
//
//  Init / Dispose
//
//=========================================================

//-------------------------------------
// function : GenericControlReader::GenericControlReader
//-------------------------------------
GenericControlReader::GenericControlReader( ISpeakable * speaker )
	: ControlReader( speaker )
{}

//-------------------------------------
// function : GenericControlReader::GenericControlReader
//-------------------------------------
GenericControlReader::~GenericControlReader()
{}


//=============================================================================
//
//  ControlReader interface
//
//=============================================================================

//-------------------------------------
// function : GenericControlReader::CanHandleContext
// brief    : determine whether this class can handle the event sent from AccessBridge
//-------------------------------------
bool
GenericControlReader::CanHandleContext( long, AccessibleContext, AccessibleContextInfo & )
{
	// because this is a reader for generic controls, always true.
	return true;
}


//-------------------------------------
// function : GenericControlReader::OnFocusGained
//-------------------------------------
void
GenericControlReader::OnFocusGained( long vmID, FocusEvent event, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	wstring format;

	// in some cases, this event was occur when the OTHER control have focused.
	// so in such cases, ignore this event.
	if( wcsstr(contextInfo.states_en_US, L"focused") == NULL )
	{
		return;
	}

	format = Utl::GetString( "GenericControlReader.Format", "{0} {1}" );

	// speak
	_SpeakerRef->ShutUp();
	_SpeakerRef->Speak( Utl::Format(format.c_str(), contextInfo.name, contextInfo.role) );
	_SpeakerRef->Wait( true );

	ControlReader::OnFocusGained( vmID, event, context, contextInfo );
}


/**********************************************************
Copyright (c) 2006-2007 YAMAMOTO Suguru

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
**********************************************************/
