// file    : MenuItemReader.cpp
// brief   : defines "control reader" for menu items
// author  : SGRY (YAMAMOTO Suguru)
// update  : 2007-06-15 (SGRY)
// license : MIT License (see END of this file)
//=========================================================
#include "MenuItemReader.h"

//=========================================================
//
//   Init / Dispose
//
//=========================================================

MenuItemReader::MenuItemReader( ISpeakable * speaker )
	: ControlReader( speaker )
{}

MenuItemReader::~MenuItemReader()
{}


//=========================================================
//
//    ControlReader interface
//
//=========================================================

//-------------------------------------
// function : MenuItemReader::CanHandleContext
// brief    : determine whether this class can handle the event sent from AccessBridge
//-------------------------------------
bool
MenuItemReader::CanHandleContext( long vmID, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	// check if the context was from proper Swing control
	if( wcscmp(contextInfo.role_en_US, ACCESSIBLE_MENU_ITEM) != 0 )
	{
		return false;
	}

	return true;
	vmID, context;
}

//-------------------------------------
// function : MenuItemReader::OnFocusGained
//-------------------------------------
void
MenuItemReader::OnFocusGained( long vmID, FocusEvent event, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	bool disabled = false;
	bool opensNewWindow = false;
	wstring label;

	// determine whether the item was disabled or not
	if( wcsstr(contextInfo.states_en_US, L"enabled") == 0 )
	{
		disabled = true;
	}

	// if the label ends with "...", speak as the SR reads in native window.
	// otherwise, simply read the label
	label = contextInfo.name;
	if( Utl::EndsWith(contextInfo.name, L"...") )
	{
		opensNewWindow = true;

		// erase trailing "..."
		label.resize( label.length() - 3 );
	}

	// speak
	_SpeakerRef->ShutUp();
	if( disabled )
	{
		_SpeakerRef->SpeakLow( label );
		if( opensNewWindow )
			_SpeakerRef->SpeakLow( _SpeakerRef->GetTextForTripleDots() );
	}
	else
	{
		_SpeakerRef->Speak( label );
		if( opensNewWindow )
			_SpeakerRef->Speak( _SpeakerRef->GetTextForTripleDots() );
	}
	_SpeakerRef->Wait( true );

	ControlReader::OnFocusGained( vmID, event, context, contextInfo );
}

//-------------------------------------
// function : MenuItemReader::OnMenuSelected
//-------------------------------------
void
MenuItemReader::OnMenuSelected( long vmID, jobject event, AccessibleContext context )
{
	vmID, event; context;
}


/**********************************************************
Copyright (c) 2006-2007 YAMAMOTO Suguru

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
**********************************************************/
