// file    : MenuReader.cpp
// brief   : defines "control reader" for menu with child items
// author  : SGRY (YAMAMOTO Suguru)
// update  : 2007-03-01 (SGRY)
// license : MIT License (see END of this file)
//=========================================================
#include "MenuReader.h"

//=========================================================
//
//   Init / Dispose
//
//=========================================================

MenuReader::MenuReader( ISpeakable * speaker )
	: ControlReader( speaker )
{}

MenuReader::~MenuReader()
{}


//=========================================================
//
//    ControlReader interface
//
//=========================================================

//-------------------------------------
// function : MenuReader::CanHandleContext
// brief    : determine whether this class can handle the event sent from AccessBridge
//-------------------------------------
bool
MenuReader::CanHandleContext( long vmID, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	// check if the context was from proper Swing control
	if( wcscmp(contextInfo.role_en_US, ACCESSIBLE_MENU) != 0 )
	{
		return false;
	}

	return true;
	vmID, context;
}

//-------------------------------------
// function : MenuReader::OnFocusGained
//-------------------------------------
void
MenuReader::OnFocusGained( long vmID, FocusEvent event, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	// because there are "menu selected" events for JMenu,
	// ignore focus event for JMenus
	ControlReader::OnFocusGained( vmID, event, context, contextInfo );
}

//-------------------------------------
// function : MenuReader::OnMenuDeselected
// brief    : action after a menu was closed
// notes    : for now, it's hard to determine "menu closed" event from MenuDeselected
//-------------------------------------
void
MenuReader::OnMenuDeselected( long vmID, jobject event, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	/*
	// if a menu was deselected because user selected another one,
	// ignore this event
	if( wcsstr(contextInfo.states_en_US, L"selected") == NULL )
	{
		return;
	}

	// speak
	_SpeakerRef->ShutUp();
	_SpeakerRef->SpeakAndWait( L"menu closed" );*/

	ControlReader::OnMenuDeselected( vmID, event, context, contextInfo );
}

//-------------------------------------
// function : MenuReader::OnMenuSelected
// brief    : action after a menu was selected
//-------------------------------------
void
MenuReader::OnMenuSelected( long vmID, jobject event, AccessibleContext context, AccessibleContextInfo & contextInfo )
{
	bool disabled = false;

	// determine whether the item was disabled or not
	if( wcsstr(contextInfo.states_en_US, L"enabled") == 0 )
	{
		disabled = true;
	}

	// speak
	_SpeakerRef->ShutUp();
	if( disabled )
	{
		_SpeakerRef->SpeakLow( contextInfo.name );
		_SpeakerRef->SpeakLow( Utl::GetString("MenuReader.Type", "menu") );
	}
	else
	{
		_SpeakerRef->Speak( contextInfo.name );
		_SpeakerRef->Speak( Utl::GetString("MenuReader.Type", "menu") );
	}
	_SpeakerRef->Wait( true );

	ControlReader::OnMenuSelected( vmID, event, context, contextInfo );
}


/**********************************************************
Copyright (c) 2006-2007 YAMAMOTO Suguru

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
**********************************************************/
