// file    : ConsoleSpeaker.cpp
// brief   : class to handle console (stdout) as a speaker
// author  : SGRY (YAMAMOTO Suguru)
// update  : 2007-06-15 (SGRY)
// license : MIT License (see END of this file)
//=========================================================
#include "Speakers/ConsoleSpeaker.h"
#include "Utilities.h"

//=============================================================================
//
//      Init / Dispose
//
//=============================================================================

//-------------------------------------
// function : ConsoleWriter::ConsoleWriter
// brief    : initialize object
//-------------------------------------
ConsoleWriter::ConsoleWriter()
{}


//-------------------------------------
// function : ConsoleWriter::~ConsoleWriter
// brief    : dispose object
//-------------------------------------
ConsoleWriter::~ConsoleWriter()
{
}


//-------------------------------------
// function : ConsoleWriter::Init
// brief    : do preparation to use PC-Talker as the speaker
// returns  : (success) ... 0
//            (failure) ... -1
//-------------------------------------
int
ConsoleWriter::Init()
{
	// no reason to fail
	return 0;
}


void
ConsoleWriter::Speak( const wchar_t * str )
{
	std::cout << Utl::Narrow( str );
}

void
ConsoleWriter::SpeakLow( const wchar_t * str )
{
	std::cout << Utl::Narrow( str );
}

void
ConsoleWriter::SpeakAndWait( const wchar_t * str )
{
	std::cout << Utl::Narrow( str );
}

void
ConsoleWriter::Wait( bool waitLong )
{
	if( waitLong )
		std::cout << "<br>" << std::endl;
	else
		std::cout << "<>";
}

void
ConsoleWriter::ShutUp()
{
	std::cout << std::endl;
}

wstring
ConsoleWriter::GetTextForTripleDots()
{
	return wstring( L"..." );
}

/**********************************************************
Copyright (c) 2006-2007 YAMAMOTO Suguru

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
**********************************************************/
