/** @file	Utilities.h
 *  @brief	defines project common utilities
 *  @date	2007-06-15 (SGRY)
 */
/*  license	MIT License (see end of this file)
 **********************************************/
#pragma once

#include <iostream>
#include <string>
#include <sstream>

#include <AccessBridgeCalls.h>
#include "Sgry/Ini.h"

using Sgry::string;
using Sgry::stringstream;
using Sgry::wstring;
using Sgry::wstringstream;

/*!
 * @namespace	Utl
 * @brief		Namespace for project common utilities.
 */
namespace Utl
{
	//-------------------------------------
	//   function	LoadStringResource
	//! @brief		load strings from resource file
	//-------------------------------------
	void LoadStringResource();

	//-------------------------------------
	//   function	GetString
	//! @brief		get string resource by name
	//-------------------------------------
	wstring GetString( const char* resourceName, const char* defaultValue );

	//-------------------------------------
	//   function	GetLabelFor
	//! @brief		get label text for a component
	//! @retval		(success) ... formatted string
	//! @retval		(failure) ... empty string
	//-------------------------------------
	wstring GetLabelFor( long vmID, AccessibleContext context, int indexInParent );
	
	//-------------------------------------
	//   function	GetChildInfo
	//! @brief		get AccessibleInfo of the child at specified index
	//! @retval		(success) ... 0
	//! @retval		(failure) ... -1
	//-------------------------------------
	int GetChildInfo( long vmID, AccessibleContext & parent, int childIndex, AccessibleContext & out_prev, AccessibleContextInfo & out_prevInfo );

	//-------------------------------------
	//   function	EndsWith
	//! @brief		determine if the string ends with another string
	//-------------------------------------
	bool EndsWith( const wstring & str, const wchar_t * subStr );

	//-------------------------------------
	//   function	EndsWith
	//! @brief		determine if the string ends with another string
	//-------------------------------------
	bool EndsWith( const wchar_t * str, const wchar_t * subStr );
	
	//-------------------------------------
	//   function	Format
	//! @brief		create formatted string with ordered parameters
	//! @param		format ... format with ordered parameters like "{0}".
	//! @returns	(success) ... formatted string
	//!				(failure) ... empty string
	//! @note		Parameter must be Sgry::wchar*. Cannot handle over 2k bytes string.
	//-------------------------------------
	wstring Format( const wchar_t * format, ... );

	//-------------------------------------
	//   function	to_s
	//! @brief		convert to a string
	//-------------------------------------
	static inline wstring
	to_s( int n ) // this name was borrowed by Ruby language :)
	{
		wchar_t buf[32];
		swprintf( buf, L"%d", n );
		return wstring( buf );
	}

	//-------------------------------------
	//   function	Narrow
	//! @brief		Convert wstring to string.
	//! @retval		(success) ... converted string object
	//! @retval		(failure) ... empty string
	//-------------------------------------
	string Narrow( const wstring & str );
}


/**********************************************************
Copyright (c) 2006-2007 YAMAMOTO Suguru

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
**********************************************************/
