// file    : main.cpp
// brief   : application entry point
// author  : SGRY (YAMAMOTO Suguru)
// update  : 2007-05-27 (SGRY)
// license : MIT License (see END of this file)
//=========================================================
#include <windows.h>
#include <AccessBridgeCalls.h>
#include <iostream>
#include <vector>
#include "SwingEventServer.h"
#include "Utilities.h"

inline static void AlertNotify( const wstring & message );
inline static void AlertError( const wstring & message );
HINSTANCE gInstanceHdl = NULL;

//-------------------------------------
// function : main
// brief    : application entry point
//-------------------------------------
int
main( int /*argc*/, char* /*argv*/ )
{
	int rc = 0; // return code
	gInstanceHdl = GetModuleHandle( NULL );
	SwingEventServer server;

	// load string resources
	Utl::LoadStringResource();

	// initialize AccessBridge library
	rc = initializeAccessBridge();
	if( rc == FALSE )
	{
		AlertError( Utl::GetString("FailedToInitAccessBridge", "Failed to initialize AccessBridge") );
		rc = 1;
		goto cleanup;
	}

	// create java accessibility event server and begin service
	rc = server.Init();
	if( rc != 0 )
	{
		AlertError( Utl::GetString("FailedToInitEventServer", "Failed to initialize Java accessibility event server") );
		rc = 1;
		goto cleanup;
	}

	// wait
	AlertNotify( Utl::GetString("SwingReaderIsRunning", "SwingReader is running. Press Enter to exit.") );
	
cleanup:
	shutdownAccessBridge();
	
	return rc;
}


inline static void
AlertNotify( const wstring & message )
{
	MessageBoxW( NULL, (wchar_t*)message.c_str(), L"SwingReader", MB_OK );
}
inline static void
AlertError( const wstring & message )
{
	MessageBoxW( NULL, (wchar_t*)message.c_str(), L"SwingReader", MB_OK | MB_ICONERROR );
}


/**********************************************************
Copyright (c) 2006-2007 YAMAMOTO Suguru

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell 
copies of the Software, and to permit persons to whom the Software is 
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in
all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, 
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER 
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN 
THE SOFTWARE.
**********************************************************/
